'use strict'

exports.WIDGETS = []

const Async = require('async')
const defaultConfig = require('../lib/default-config')
const DB = require('../couchbase')
const Log = require('xnpmlog')
const mock = process.env.MOCK_COUCHBASE
const uuid = require('node-uuid')

const log = new Log('couchbase-segfault', {
  timestamps: true
  , heading: 'couchbase-segfault'
  , level: 'info'
})

const db = new DB({
  uri: 'http://couchbase-db'
  , mock: mock
  , log: log
})

const SEED_CONFIGS = [
  {
    id: uuid.v4()
  , organization_id: uuid.v4()
  , colors: {}
  , depts: {[uuid.v4()]: 'Department 1'}
  }
, {
    id: uuid.v4()
  , organization_id: uuid.v4()
  , colors: { bodyBackground: '#0f0'}
  , depts: {
      [uuid.v4()]: 'Department 1'
      , [uuid.v4()]: 'Department 2'
    }
  }
, {
    id: uuid.v4()
  , organization_id: uuid.v4()
  , colors: {bodyBackground: '#f00'}
  , depts: {
      [uuid.v4()]: 'Department 1'
      , [uuid.v4()]: 'Department 2'
      , [uuid.v4()]: 'Department 3'
    }
  }
]

exports.seed = function seed(cb) {
  db.connect(['widgets'], (err) => {
    if (err) return cb(err)
    console.log('creating widgets')

    SEED_CONFIGS.forEach((field) => {
      exports.WIDGETS.push(makeConfig(field))
    })

    Async.eachSeries(exports.WIDGETS, (config, cb) => {
      createWidget(config, cb)
    }, (err) => {
      console.log('disconnecting...')
      setImmediate(() => {
        db.disconnect()
        cb(err)
      })
    })
  })
}

function makeConfig(opts) {
  // assign colors to widgets.colors
  // assign depts to widget.prechatSurvey.formFields select list
  let conf = JSON.parse(JSON.stringify(defaultConfig))
  conf.id = opts.id
  conf.organization_id = opts.organization_id
  conf.widget.prechatSurvey.formFields.forEach((field, index, array) => {
    if (field.type === 'select') {
      array[index].data = opts.depts
      return
    }
  })
  return conf
}

function createWidget(config, cb) {
  db.insert('widgets', config.id, config, (err) => {
    if (err) {
      console.log(`unable to insert widget ${config.id} ${err}`)
      return cb(err)
    }

    console.log(`widget inserted ${config.id}`)
    return cb()
  })
}

if (require.main === module) {
  exports.seed((err) => {
    if (err) throw err
  })
}
